summaryrefslogtreecommitdiff
path: root/ext/standard/math.c
diff options
context:
space:
mode:
authorAndrey Hristov <andrey@php.net>2005-05-10 12:50:53 +0000
committerAndrey Hristov <andrey@php.net>2005-05-10 12:50:53 +0000
commitf12b14078e48d4385e75c2bb63bd6a60d367eba0 (patch)
tree050998bbefe26ae8541c23d1e8be507509dc9d8a /ext/standard/math.c
parent924b4c016df24937be1259c76d3bfa47aae76149 (diff)
downloadphp-git-f12b14078e48d4385e75c2bb63bd6a60d367eba0.tar.gz
rename math_std_dev to math_standard_deviation (the API wasn't published
yet)
Diffstat (limited to 'ext/standard/math.c')
-rw-r--r--ext/standard/math.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/ext/standard/math.c b/ext/standard/math.c
index 68a61ddfbe..62bce33389 100644
--- a/ext/standard/math.c
+++ b/ext/standard/math.c
@@ -1193,9 +1193,9 @@ PHP_FUNCTION(math_variance)
}
/* }}} */
/* {{{ proto float math_std_dev(array a [, bool sample])
Returns the standard deviation */
-PHP_FUNCTION(math_std_dev)
+PHP_FUNCTION(math_standard_deviation)
{
zval *arr;
zend_bool sample = 0;
@@ -1193,9 +1193,9 @@ PHP_FUNCTION(math_variance)
}
/* }}} */
-/* {{{ proto float math_std_dev(array a [, bool sample])
+/* {{{ proto float math_standard_deviation(array a[, bool sample = false])
Returns the standard deviation */